@@ -1,15 +1,27 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
 
-import click
-import sys
 import os
 import os.path as osp
 import subprocess
+import sys
 from pathlib import Path
 
-from mathicsscript.termshell import ShellEscapeException, mma_lexer
+import click
+from mathics.core.attributes import attribute_string_to_number
+from pygments import highlight
 
+from mathics import license_string, settings, version_info
+from mathics.core.definitions import autoload_files
+from mathics.core.evaluation import Evaluation, Output
+from mathics.core.expression import from_python
+from mathics.core.parser import MathicsFileLineFeeder
+from mathics.core.symbols import Symbol, SymbolFalse, SymbolTrue
+
+from mathics_scanner import replace_wl_with_plain_text
+
+from mathicsscript.asymptote import asymptote_version
+from mathicsscript.termshell import ShellEscapeException, mma_lexer
 from mathicsscript.termshell_gnu import TerminalShellGNUReadline
 from mathicsscript.termshell_prompt import TerminalShellPromptToolKit
 
@@ -22,18 +34,31 @@ else:
     readline_choices = ["GNU", "Prompt", "None"]
     have_readline = True
 
-from mathicsscript.format import format_output
 
-from mathics_scanner import replace_wl_with_plain_text
-from mathics.core.parser import MathicsFileLineFeeder
-from mathics.core.definitions import autoload_files, Definitions
-from mathics.core.expression import Symbol, SymbolTrue, SymbolFalse
-from mathics.core.evaluation import Evaluation, Output
-from mathics.core.expression import from_python
-from mathics import version_string, license_string
-from mathics import settings
+from mathicsscript.format import format_output, matplotlib_version
 
-from pygments import highlight
+version_string = """Mathics {mathics}
+on {python}
+
+Using:
+SymPy {sympy}, mpmath {mpmath}, numpy {numpy}
+""".format(
+    **version_info
+)
+
+
+if "cython" in version_info:
+    version_string += f"cython {version_info['cython']}, "
+
+if matplotlib_version is None:
+    version_string += "\nNo matplotlib installed,"
+else:
+    version_string += f"matplotlib {matplotlib_version},"
+
+if asymptote_version is None:
+    version_string += "\nNo asymptote installed,"
+else:
+    version_string += f"\n{asymptote_version}"
 
 
 def get_srcdir():
@@ -41,6 +66,7 @@ def get_srcdir():
     return osp.realpath(filename)
 
 
+from mathicsscript.settings import definitions
 from mathicsscript.version import __version__
 
 
@@ -61,14 +87,14 @@ def ensure_settings():
         try:
             with open(srcfn, "r") as src:
                 buffer = src.readlines()
-        except:
+        except IOError:
             print(f"'{srcfn}' was not found.")
             return ""
         try:
             with open(settings_file, "w") as dst:
-                for l in buffer:
-                    dst.write(l)
-        except:
+                for c in buffer:
+                    dst.write(c)
+        except IOError:
             print(f" '{settings_file}'  cannot be written.")
             return ""
     return settings_file
@@ -240,7 +266,6 @@ def main(
         for ext in pyextensions:
             extension_modules.append(ext)
 
-    definitions = Definitions(add_builtin=True)
     definitions.set_line_no(0)
     # Set a default value for $ShowFullFormInput to False.
     # Then, it can be changed by the settings file (in WL)
@@ -344,8 +369,12 @@ def main(
         "Settings`$PygmentsShowTokens", from_python(pygments_tokens)
     )
     definitions.set_ownvalue("Settings`MathicsScriptVersion", from_python(__version__))
-    definitions.set_attribute("Settings`MathicsScriptVersion", "System`Protected")
-    definitions.set_attribute("Settings`MathicsScriptVersion", "System`Locked")
+    definitions.set_attribute(
+        "Settings`MathicsScriptVersion", attribute_string_to_number["System`Protected"]
+    )
+    definitions.set_attribute(
+        "Settings`MathicsScriptVersion", attribute_string_to_number["System`Locked"]
+    )
     TeXForm = Symbol("System`TeXForm")
 
     definitions.set_line_no(0)
@@ -407,15 +436,15 @@ def main(
             if len(source_code) and source_code[1] == "!":
                 try:
                     print(open(source_code[2:], "r").read())
-                except:
+                except Exception:
                     print(str(sys.exc_info()[1]))
             else:
                 subprocess.run(source_code[1:], shell=True)
 
                 # Should we test exit code for adding to history?
                 GNU_readline.add_history(source_code.rstrip())
-                ## FIXME add this... when in Mathics core updated
-                ## shell.defintions.increment_line(1)
+                # FIXME add this... when in Mathics core updated
+                # shell.defintions.increment_line(1)
 
         except (KeyboardInterrupt):
             print("\nKeyboardInterrupt")
